"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("../util/color");
const createPaletteItem = (paletteItem, theme) => {
    var _a;
    var _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u;
    let result = {
        popover: {},
        progressBar: {},
        tooltip: {},
    };
    if (typeof paletteItem === 'string') {
        result.main = paletteItem;
    }
    else {
        result = Object.assign(Object.assign({}, result), paletteItem);
        if (!result.main) {
            console.error('Palette main color is missing...');
        }
    }
    const mainColor = (0, color_1.getColor)(result.main);
    result.background || (result.background = result.main);
    result.font || (result.font = (0, color_1.getFontColor)(result.main, theme));
    result.shadow || (result.shadow = mainColor.alpha(.5).rgb().toString());
    result.dark || (result.dark = mainColor.darken(.075).hex().toString());
    result.darker || (result.darker = mainColor.darken(.175).hex().toString());
    result.darkest || (result.darkest = (0, color_1.getColor)(result.darker).darken(.075).hex().toString());
    result.light || (result.light = mainColor.lighten(.075).hex().toString());
    result.lighter || (result.lighter = mainColor.lighten(.175).hex().toString());
    result.lightest || (result.lightest = (0, color_1.getColor)(result.lighter).lighten(.075).hex().toString());
    result.dynamic = theme.$.vars.isDarkMode ? result.light : result.dark;
    result.dynamicer = theme.$.vars.isDarkMode ? result.lighter : result.darker;
    result.dynamicest = theme.$.vars.isDarkMode ? result.lightest : result.darkest;
    result.soft || (result.soft = (0, color_1.mix)(result.main, -.8));
    result.softFont || (result.softFont = (0, color_1.mix)(result.main, .4));
    result.softDark || (result.softDark = (0, color_1.mix)(result.main, -.72));
    result.softDarker || (result.softDarker = (0, color_1.mix)(result.main, -.65));
    result.softDarkest || (result.softDarkest = (0, color_1.mix)(result.main, -.55));
    (_b = result.popover).background || (_b.background = theme.$.color.dynamic.background);
    (_c = result.popover).border || (_c.border = theme.$.color.dynamic.accent);
    (_d = result.popover).font || (_d.font = theme.$.color.dynamic.font);
    (_e = result.popover).headerBackground || (_e.headerBackground = result.main);
    (_f = result.popover).headerBorder || (_f.headerBorder = theme.$.vars.isDarkMode ? result.lighter : result.darker);
    (_g = result.popover).headerFont || (_g.headerFont = result.font);
    (_h = result.popover).softHeaderBackground || (_h.softHeaderBackground = result.soft);
    (_j = result.popover).softHeaderBorder || (_j.softHeaderBorder = result.softDarker);
    (_k = result.popover).softHeaderFont || (_k.softHeaderFont = result.softFont);
    (_l = result.progressBar).active || (_l.active = result.main);
    (_m = result.progressBar).filledBackground || (_m.filledBackground = theme.$.color.dynamic.gray);
    (_o = result.progressBar).font || (_o.font = result.font);
    (_p = result.progressBar).nestedBackground || (_p.nestedBackground = (0, color_1.getColor)(theme.$.color.light.background).alpha(.3).rgb().toString());
    (_q = result.tooltip).background || (_q.background = result.background);
    (_r = result.tooltip).font || (_r.font = result.font);
    (_s = result.tooltip).softBackground || (_s.softBackground = result.soft);
    (_t = result.tooltip).softFont || (_t.softFont = result.softFont);
    (_u = result.tooltip).shadow || (_u.shadow = theme.$.color.dynamic.shadow);
    const waveEffect = (0, color_1.getColor)((_a = result.waveEffect) !== null && _a !== void 0 ? _a : result.main);
    result.waveEffect = `radial-gradient(${waveEffect.alpha(.2).toString()} 0, ${waveEffect.alpha(.3).toString()} 40%, ${waveEffect.alpha(.4).toString()} 50%, ${waveEffect.alpha(.5).toString()} 60%, ${waveEffect.alpha(0).toString()} 70%)`;
    return result;
};
exports.default = createPaletteItem;
